@@ -194,12 +194,12 @@ class CGCalendar extends CGExtensions
 
   function GetVersion()
     {
-      return '1.5.7';
+      return '1.6';
     }
 
   function GetDependencies()
     {
-      return array('CGExtensions'=>'1.19.4');
+      return array('CGExtensions'=>'1.24');
     }
 
   function GetDescription($lang = 'en_US')
@@ -224,7 +224,7 @@ class CGCalendar extends CGExtensions
 
   function MinimumCMSVersion()
     {
-      return '1.8.1';
+      return '1.9.1';
     }
 
   function GetChangeLog()
@@ -249,7 +249,7 @@ class CGCalendar extends CGExtensions
 
   function GetEvent($event_id)
     {
-      $db =& $this->GetDb(); /* @var $db ADOConnection */
+      $db = $this->GetDb(); /* @var $db ADOConnection */
 
       $sql = 'SELECT * FROM ' . $this->events_table_name .' WHERE event_id = ?';
       $rs = $db->Execute($sql,array($event_id));
@@ -350,7 +350,7 @@ class CGCalendar extends CGExtensions
 
   function GetEventFromParams(&$event,$params,$is_edit = false)
     {
-	  $db =& $this->GetDb();
+	  $db = $this->GetDb();
 	  if( isset($params['event_id']) )
 		{
 		  $event['event_id'] =  (int)$params['event_id'];
@@ -495,7 +495,7 @@ class CGCalendar extends CGExtensions
 
   function GetCategories($order_by='category_order, category_name')
     {
-      $db =& $this->GetDb(); /* @var $db ADOConnection */
+      $db = $this->GetDb(); /* @var $db ADOConnection */
       $categories_table_name = $this->categories_table_name;
       $sql = "SELECT * FROM $categories_table_name";
       if($order_by != '')
@@ -512,7 +512,7 @@ class CGCalendar extends CGExtensions
 
   function GetCategoryName($id)
   {
-	$db =& $this->GetDb();
+	$db = $this->GetDb();
 	$sql = 'SELECT name FROM '.$this->categories_table_name.'
              WHERE id = ?';
 	$name = $db->GetOne($query,array($id));
@@ -553,7 +553,7 @@ class CGCalendar extends CGExtensions
 
   function GetFields()
     {
-      $db =& $this->GetDb(); /* @var $db ADOConnection */
+      $db = $this->GetDb(); /* @var $db ADOConnection */
       $fields_table_name = $this->fields_table_name;
       $sql = "SELECT * FROM $fields_table_name ORDER BY field_name";
 
@@ -569,7 +569,7 @@ class CGCalendar extends CGExtensions
 
   function AdminDeleteField($field_oldname)
     {
-      $db =& $this->GetDb(); /* @var $db ADOConnection */
+      $db = $this->GetDb(); /* @var $db ADOConnection */
       $fields_table_name = $this->fields_table_name;
       $event_field_values_table_name = $this->event_field_values_table_name;
 	  
@@ -582,7 +582,7 @@ class CGCalendar extends CGExtensions
 	
   function AdminAddField($field_newname,$field_type = 0,$field_searchable = 0)
     {
-      $db =& $this->GetDb(); /* @var $db ADOConnection */
+      $db = $this->GetDb(); /* @var $db ADOConnection */
       $sql = 'INSERT INTO ' . $this->fields_table_name . '
                 (field_name,field_type,field_searchable)
               VALUES (?,?,?)';
@@ -591,7 +591,7 @@ class CGCalendar extends CGExtensions
 	
   function AdminUpdateField($field_oldname,$field_newname,$field_type = 0,$field_searchable = 0)
     {
-      $db =& $this->GetDb(); /* @var $db ADOConnection */
+      $db = $this->GetDb(); /* @var $db ADOConnection */
 
       $sql = 'UPDATE ' . $this->fields_table_name . '
                  SET field_name = ?, field_type = ?, field_searchable = ?
@@ -703,7 +703,7 @@ class CGCalendar extends CGExtensions
 	  return $result;
 	}
 		  
-      $db =& $this->GetDb();
+      $db = $this->GetDb();
       $query = 'SELECT event_title FROM '.$this->events_table_name.' WHERE event_id = ?';
       $title = $db->GetOne( $query, array($event_id) );
 		  
@@ -731,10 +731,10 @@ class CGCalendar extends CGExtensions
 		
   function SearchReindex(&$module)
     {
-      $db =& $this->GetDb();
+      $db = $this->GetDb();
 
       $query = 'SELECT * FROM '.$this->events_table_name.' ORDER BY event_date_start';
-      $dbr =& $db->Execute($query);
+      $dbr = $db->Execute($query);
 
 	  $fquery = 'SELECT fv.field_value FROM '.$this->fields_table_name.' fd 
                    LEFT JOIN '.$this->event_field_values_table_name.' fv 
