@@ -48,7 +48,7 @@ function DisplayUpcomingList(&$module, $id, &$parameters, $returnid)
   if (isset($parameters['detailpage']))
     {
       $manager =& $gCms->GetHierarchyManager();
-      $node =& $manager->sureGetNodeByAlias($parameters['detailpage']);
+      $node = $manager->sureGetNodeByAlias($parameters['detailpage']);
       if (isset($node))
 	{
 	  $content =& $node->GetContent();
