@@ -367,14 +367,14 @@ $lang['help_template'] = '<p><b>Affiche le nom de l&#039;auteur :</b></p>
 <code>Auteur : {$event.authorname}</code>
 ';
 $lang['cal_help'] = '		<h3>Notice:</h3>
-		<p>Le module CGCalendrier (Calguy Calendar) est un fork du module de Calendrier classique, mais CGCalendrier n&#039;est aucunement compatible avec Calendrier.
+		<p>Le module CGCalendrier (Calguy Calendar) Version 1.0  est un fork du module de Calendrier classique, mais CGCalendrier n&#039;est aucunement compatible avec Calendrier.
 		<h3>Que fait ce module ?</h3>
 		<p>Ce module affiche des &eacute;v&eacute;nements sur vos pages. D&egrave;s que le module est install&eacute;, une page de gestion des &eacute;v&eacute;nements est ajout&eacute;e au menu d&#039;administration qui vous permettra de g&eacute;rer des &eacute;v&eacute;nements.</p>
 		<h3>S&eacute;curit&eacute;</h3>
 		<p>L&#039;utilisateur doit faire partie d&#039;un groupe avec la permission &#039;Modify Calendar&#039; pour pouvoir ajouter, &eacute;diter ou supprimer des &eacute;v&eacute;nements.</p>
 		<h3>Comment l&#039;utiliser?</h3>
 		<ol>
-		  <li>Le module calendrier est utilis&eacute; en conjonction avec le tag cms_module. Veuillez vous assurer que le tag n&#039;est pas inclus dans les balises &amp;lt;pre&amp;gt; ... &amp;lt;/pre&amp;gt; Vous aurez besoin d&#039;afficher le code source pour cela. Cela ins&eacute;rera votre module dans votre gabarit ou votre page o&ugrave; vous le d&eacute;sirez, et y affichera le calendrier.  Exemple de synthaxe:<br />
+		  <li>Le module calendrier est utilis&eacute; en conjonction avec le tag cms_module. Veuillez vous assurer que le tag n&#039;est pas inclus dans les balises &amp;lt;pre&amp;gt; ... &amp;lt;/pre&amp;gt; Vous aurez besoin d&#039;afficher le code source pour cela. Cela ins&eacute;rera votre module dans votre gabarit ou votre page o&ugrave; vous le d&eacute;sirez, et y affichera le calendrier.  Exemple de syntaxe:<br />
 		<tt>{cms_module module=&#039;CGCalendar&#039;}</tt><br />
 		  <li>&Eacute;ditez la feuille de style d&#039;exemple qui a &eacute;t&eacute; ins&eacute;r&eacute;e dans la liste de vos feuilles de style.</li>
 		  <li>Associez cette feuille de style au gabarit que vous utilisez pour les pages de calendrier.</li>
@@ -401,12 +401,14 @@ $lang['cal_help'] = '		<h3>Notice:</h3>
                 &quot;default&quot; - indique d&#039;utiliser l&#039;action par d&eacute;faut, fonctionne en conjonction avec le param&egrave;tre &quot;display&quot; ci-dessous.<br/>
                 &quot;search&quot; - affiche un formulaire de recherche avanc&eacute;e d&#039;&eacute;v&eacute;nement du calendrier.
                 &quot;myevents&quot; - affiche une liste contenant tous les &eacute;v&eacute;nements d&#039;un utilisateur et permet d&#039;ajouter, &eacute;diter ou supprimer ces &eacute;v&eacute;nements.
+               &quot;addedit_event&quot; - Display a form allowing to add or edit a single event.;
 		</td>
 		</tr>
 
 			<tr>
 			<td>display (Affichage)</td>
-			<td>&quot;calendar&quot; (calendrier) - affiche les &eacute;v&eacute;nements pour le mois en cours dans une grille traditionnelle. Inclus les liens suivant et pr&eacute;c&eacute;dent au mois concern&eacute;.<br />
+			<td>Valeur accept&eacute;es:<br>
+&quot;calendar&quot; (calendrier) - affiche les &eacute;v&eacute;nements pour le mois en cours dans une grille traditionnelle. Inclus les liens suivant et pr&eacute;c&eacute;dent au mois concern&eacute;.<br />
 &quot;event&quot; (&eacute;v&eacute;nement) - affiche les d&eacute;tails d&#039;un &eacute;v&eacute;nement en particulier. Pour l&#039;utiliser, le param&egrave;tre event_id doit &ecirc;tre sp&eacute;cifi&eacute;.<br />
 &quot;list&quot; (liste) - affiche les &eacute;v&eacute;nements pour le mois en cours sous forme de liste. Inclus les liens suivant et pr&eacute;c&eacute;dent au mois concern&eacute;.<br />
 &quot;yearlist&quot; (liste annuelle) - affiche les &eacute;v&eacute;nements pour l&#039;ann&eacute;e en cours sous forme de liste. Inclus les liens suivant et pr&eacute;c&eacute;dent &agrave; l&#039;ann&eacute;e concern&eacute;e.<br />
@@ -514,12 +516,13 @@ Par exemple, si vous avez un gabarit nomm&eacute; &quot;blog-post-list-with-cont
 		<pre style=&quot;font-size: 12px&quot;>{cms_module module=&#039;CGCalendar&#039; table_id=&#039;big&#039;}</pre></p>
 
 		<h3>Champs personnalis&eacute;s</h3>
-		<p>Il est possible de d&eacute;finir des champs personnalis&eacute;s &agrave; associer avec chaque &eacute;v&eacute;nement au moyen de l&#039;onglet &quot;Champs&quot; dans le panneau d&#039;administration du module. Une fois qu&#039;un ou plusieurs champ(s) aient &eacute;t&eacute; d&eacute;finis, les valeurs de ce champ pour chaque &eacute;v&eacute;nement peuvent &ecirc;tre d&eacute;finies au moyen de l&#039;onglet &quot;&Eacute;v&eacute;nements&quot; dans l&#039;administration. Les valeurs de ces champs peuvent &ecirc;tre obtenue avec l&#039;utilisation d&#039;un gabarit ayant la synthaxe event.fields.fieldname. Astuce - ins&eacute;rez {debug} dans votre gabarit pour voir toutes les donn&eacute;es qui sont pass&eacute;es au gabarit.</p>
+		<p>Il est possible de d&eacute;finir des champs personnalis&eacute;s &agrave; associer avec chaque &eacute;v&eacute;nement au moyen de l&#039;onglet &quot;Champs&quot; dans le panneau d&#039;administration du module. Une fois qu&#039;un ou plusieurs champ(s) aient &eacute;t&eacute; d&eacute;finis, les valeurs de ce champ pour chaque &eacute;v&eacute;nement peuvent &ecirc;tre d&eacute;finies au moyen de l&#039;onglet &quot;&Eacute;v&eacute;nements&quot; dans l&#039;administration. Les valeurs de ces champs peuvent &ecirc;tre obtenue avec l&#039;utilisation d&#039;un gabarit ayant la syntaxe event.fields.fieldname. Astuce - ins&eacute;rez {debug} dans votre gabarit pour voir toutes les donn&eacute;es qui sont pass&eacute;es au gabarit.</p>
 
 	<h3>Exemples</h3>
 		<h4>Exemple autoriser les commentaires sur les &eacute;v&eacute;nements du calendrier</h4>
 				<p>Installez le module Commentaires et ins&eacute;rez ceci dans votre le &quot;gabarit d&#039;&eacute;v&eacute;nement&quot; de votre calendrier&amp;nssp;:</p>
 		<pre>{cms_module module=&#039;comments&#039; modulename=&#039;CGCalendar&#039; pageid=$event.event_id}</pre>
+<p>Conseil : ins&eacute;rez {debug} dans votre gabarit pour voir toutes les donn&eacute;es disponibles pass&eacute;es au gabarit</p>
 
 <h3>Support</h3>
 <p>Ce module n&#039;inclu aucun support commercial. Cependant, il y a un certain nombre de ressources disponibles pour vous aider :</p>
@@ -548,8 +551,9 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>
 ';
-$lang['utma'] = '156861353.3775108633884901000.1235391363.1284418363.1285534821.75';
-$lang['utmz'] = '156861353.1284418375.74.34.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
-$lang['qca'] = 'P0-186310954-1257243985177';
+$lang['utma'] = '156861353.1949673112.1265210769.1286953600.1286956518.214';
+$lang['utmz'] = '156861353.1286956518.214.40.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php/topic,48121.0.html|utmcmd=referral';
+$lang['qca'] = 'P0-1075820551-1265210768764';
 $lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
